@@ -1,11 +1,12 @@
 import logging
 
-from ebay_feedsdk.errors.custom_exceptions import DownloadError
-from ebay_feedsdk.feed import Feed
-from ebay_feedsdk.filter.feed_filter import GetFeedResponse
-from ebay_feedsdk.oauthclient.credentialutil import Credentialutil
-from ebay_feedsdk.oauthclient.model.model import Environment, OauthToken, EnvType
-from ebay_feedsdk.oauthclient.oauth2api import Oauth2api
+from errors.custom_exceptions import DownloadError
+from feed import Feed
+from filter.feed_filter import GetFeedResponse
+from oauthclient.credentialutil import Credentialutil
+from oauthclient.model.model import Environment, OauthToken, EnvType
+from oauthclient.oauth2api import Oauth2api
+
 
 class EbayDownloadExample:
     app_scopes = ["https://api.ebay.com/oauth/api_scope", "https://api.ebay.com/oauth/api_scope/buy.item.feed"]
@@ -17,7 +18,7 @@ class EbayDownloadExample:
         self.market_place = market_place
         self.download_location = download_location
 
-    def download(self, category_id: str):
+    def download(self, category_id: str) -> GetFeedResponse:
         logging.info(
             f'Downloading category {category_id} for {self.market_place} with scope {self.feed_scope}'
             f'to {self.download_location}')
@@ -35,7 +36,7 @@ class EbayDownloadExample:
 
         logging.info(f'File was downloaded under {feed_response.file_path}')
 
-        return feed_response.file_path
+        return feed_response
 
     def get_token(self) -> OauthToken:
         Credentialutil.load(self.config_file)
@@ -54,5 +55,6 @@ if __name__ == "__main__":
     download_location = '/tmp/feed'
     category_id = '2984'  # string ..
     ebay_download = EbayDownloadExample(market_place, Environment.PRODUCTION, feed_scope, download_location)
-    file_path = ebay_download.download(category_id)
+    feed_response = ebay_download.download(category_id)
+    print(feed_response)
 
